<?php
/***************************************************************
*  Copyright notice
*
*  (c) 2003-2010 Renzo Lauper (renzo@churchtool.org)
*  All rights reserved
*
*  This script is part of the kOOL project. The kOOL project is
*  free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  The GNU General Public License can be found at
*  http://www.gnu.org/copyleft/gpl.html.
*  A copy is found in the textfile GPL.txt and important notices to the license
*  from the author is found in LICENSE.txt distributed with these scripts.
*
*  kOOL is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/

require($BASE_PATH."inc/class.kOOL_listview.php");


function apply_daten_filter(&$z_where, &$z_limit, $_start="", $_ende="", $_tg="") {
	global $access;

	$use_start = ($_start != "") ? $_start : $_SESSION["filter_start"];
	$use_ende = ($_ende != "") ? $_ende : $_SESSION["filter_ende"];
	$use_tg = ($_tg != "") ? $_tg : $_SESSION["show_tg"];

	//Permanenten Filter einfgen, falls vorhanden und nur view-Rechte
	$z_where = "";
	$perm_filter_start = ko_get_setting("daten_perm_filter_start");
	$perm_filter_ende  = ko_get_setting("daten_perm_filter_ende");
	if($access['daten']['MAX'] < 2 && ($perm_filter_start || $perm_filter_ende)) {
		if($perm_filter_start != "") {
			$z_where .= " AND startdatum >= '".$perm_filter_start."' ";
		}
		if($perm_filter_ende != "") {
			$z_where .= " AND startdatum <= '".$perm_filter_ende."' ";
		}
	}

	//Filter anwenden, falls gesetzt
	if(isset($use_start) && $use_start != "immer") {
		get_heute($tag, $monat, $jahr);
		if($use_start == "today") {
			$start = sql_datum($tag.".".$monat.".".$jahr);
		} else {
			addmonth($monat, $jahr, $use_start);
			$start = sql_datum("1.".$monat.".".$jahr);
		}
		$z_where .= "AND startdatum >= '$start'";
	}
	if(isset($use_ende) && $use_ende != "immer") {
		get_heute($tag, $monat, $jahr);
		if($use_ende == "today") {
			$ende = sql_datum($tag.".".$monat.".".$jahr);
		} else {
			addmonth($monat, $jahr, ($use_ende+1));
			$ende = sql_datum("0.".$monat.".".$jahr);
		}
		$z_where .= " AND startdatum <= '$ende'";
	}

	//Die gewnschten Termingruppen anzeigen
	$z_where_add = "";
	$tgs = array();
	if(is_array($use_tg)) {
		foreach($use_tg as $g) {
			if($access['daten'][$g] < 1) continue;
			$tgs[] = $g;
		}
		$z_where_add = " `eventgruppen_id` IN ('".implode("','", $tgs)."') ";
	}

	if($z_where_add) {
		$z_where .= " AND ( $z_where_add ) ";
	} else {
		//Falls nichts gefunden, ein FALSE-Bedingung einfgen!
		$z_where = " AND ( 1=2 ) ";
	}

	//Limit bestimmen
  $z_limit = "LIMIT " . ($_SESSION["show_start"]-1) . ", " . $_SESSION["show_limit"];
}//apply_daten_filter()






/**
  * Shows list of events
	* Using the data from KOTA
	*/
function ko_list_events($method, $output=TRUE) {
	global $ko_path, $smarty;
	global $access;

	if($method == "mod") {
		ko_list_mod_events("new", $output);
		ko_list_mod_events("edit", $output);
		ko_list_mod_events("delete", $output);
		return;
	}

	if($access['daten']['MAX'] < 1) return FALSE;
	apply_daten_filter($z_where, $z_limit);

	$list = new kOOL_listview();

	$rows = db_get_count("ko_event", "id", $z_where);
	ko_get_events($es, $z_where, $z_limit);

	$list->init("daten", "ko_event", array("chk", "edit", "delete"), $_SESSION["show_start"], $_SESSION["show_limit"]);
	$list->setTitle(getLL("daten_list_title"));
	$list->setAccessRights(array('edit' => 2, 'delete' => 2), $access['daten']);
	$list->setActions(array("edit" => array("action" => "edit_termin"),
													"delete" => array("action" => "delete_termin", "confirm" => TRUE))
										);
	//Add link to rota
	if(ko_module_installed("dp")) {
		$list->setColumnLink("dp", $ko_path."dp/index.php?action=show_dp&amp;date=STARTDATUM#cID", "return '@VALUE@' == '".getLL("yes")."';");
	}
	//Mark sunday with extra tr class definition
	if(ko_get_setting("daten_mark_sunday")) {
		$list->setRowClass("ko_list_sunday", 'return strftime("%w", strtotime("STARTDATUM")) == 0;');
	}

	$list->setStats($rows);
	$list->setSort(TRUE, "setsortevent", $_SESSION["sort_events"], $_SESSION["sort_events_order"]);

	//Footer for event list
	if($access['daten']['MAX'] > 1) {
		$list_footer[] = array("label" => getLL("daten_list_footer_del_label"),
													 "button" => '<input type="submit" onclick="c=confirm('."'".getLL("daten_list_footer_del_button_confirm")."'".');if(!c) return false;set_action(\'del_selected\');" value="'.getLL("daten_list_footer_del_button").'" />');
		$list->setFooter($list_footer);
	}


	if($output) {
		$list->render($es);
	} else {
		print $list->render($es);
	}
}//ko_list_events()



/**
  * Shows list of mod events
	*/
function ko_list_mod_events($mode, $output=TRUE) {
	global $ko_path, $smarty;
	global $access;

	//Don't allow guest user to see its event moderations
	if($_SESSION["ses_userid"] == ko_get_guest_id()) return FALSE;
	//Only allow moderators or users who can add new moderated events to see moderations
	if($access['daten']['MAX'] < 2) return FALSE;

	if($access['daten']['MAX'] > 3) {
		if($access['daten']['ALL'] >= 4) {
			$z_where = '';
		} else {
			$mod_eg = array();
			foreach($access['daten'] as $k => $v) {
				if(!intval($k)) continue;
				if($v >= 4) $mod_eg[] = $k;
			}
			$z_where = " AND `eventgruppen_id` IN ('".implode("','", $mod_eg)."') ";
		}
	} else {
		$z_where = " AND `_user_id` = '".$_SESSION["ses_userid"]."' ";
	}

	switch($mode) {
		case "new":
			$action_check = "daten_mod_new_approve";
			$action_delete = "daten_mod_delete";
			//Get mod events
			$z_where .= " AND `_event_id` = '0' AND `_delete` = '0'";
			$rows = db_get_count("ko_event_mod", "id", $z_where);
			ko_get_events_mod($es, $z_where, $z_limit);
		break;

		case "edit":
			$action_check = "daten_mod_edit_approve";
			$action_delete = "daten_mod_delete";
			//Get mod events
			$z_where .= " AND `_event_id` != '0' AND `_delete` = '0'";
			$rows = db_get_count("ko_event_mod", "id", $z_where);
			ko_get_events_mod($_es, $z_where, $z_limit);
			$es = array();
			foreach($_es as $mid => $me) {
				//KOTA process data here so it gets displayed nicely in the list view (processing afterwards doesn't work, because of the differences)
				$kme = $me; kota_process_data("ko_event_mod", $kme, "list", $log, $mid);
				$event = db_select_data("ko_event", "WHERE `id` = '".$me["_event_id"]."'", "*", "", "", TRUE);
				$kevent = $event; kota_process_data("ko_event", $kevent, "list", $log, $me["_event_id"]);
				//Add user id from moderated event
				$event["_user_id"] = $me["_user_id"];
				$kevent["_user_id"] = $kme["_user_id"];
				foreach($event as $key => $value) {
					if($key == "id") {
						$es[$mid]["id"] = $mid;
					} else if(in_array($key, array("reservationen", "endzeit"))) {
						continue;
					} else {
						//Merge times into one field
						if($key == "startzeit") {
							$value = $event["startzeit"]." - ".$event["endzeit"];
							$me[$key] = $me["startzeit"]." - ".$me["endzeit"];
						}
						//Keep eventgruppen_id and _user_id for fake access rights
						if($key == "eventgruppen_id") $es[$mid]["_".$key] = $value;
						if($key == "_user_id") $es[$mid]["_".$key] = $me["_user_id"];
						//Compare values and mark differences
						if($value != $me[$key]) {
							$es[$mid][$key] = '<span style="text-decoration: line-through;">'.$kevent[$key]."</span>".($kevent[$key] != "" ? "<br />" : "")."<b>".$kme[$key]."</b>";
						} else {
							$es[$mid][$key] = $kevent[$key];
						}
					}
				}//foreach(event as key => value)
			}//foreach(_es as mid => me)
		break;

		case "delete":
			$action_check = "daten_mod_delete_approve";
			$action_delete = "daten_mod_delete";
			//Get mod events
			$z_where .= " AND `_event_id` != '0' AND `_delete` = '1'";
			$rows = db_get_count("ko_event_mod", "id", $z_where);
			ko_get_events_mod($_es, $z_where, $z_limit);
			//Show values from stored events instead of event_mod entries, as the ones from ko_event might have been edited since the moderated deletion
			$es = array();
			foreach($_es as $mid => $me) {
				$event = db_select_data("ko_event", "WHERE `id` = '".$me["_event_id"]."'", "*", "", "", TRUE);
				//Add user id
				$event["_user_id"] = $me["_user_id"];
				//Reset id to id of moderated event
				$event["id"] = $me["id"];
				$es[$mid] = $event;
			}
		break;
	}
	if($rows == 0) return;

	$list = new kOOL_listview();

	//Build fake accessRights arrays (TODO: Only show check if no "Doppelbelegung" for new)
	$mod_access = array('ALL' => $access['daten']['ALL']);
	foreach($es as $e) {
		$eg_id = is_numeric($e["eventgruppen_id"]) ? $e["eventgruppen_id"] : $e["_eventgruppen_id"];
		$user_id = is_numeric($e["_user_id"]) ? $e["_user_id"] : $e["__user_id"];
		$mod_access[$eg_id] = $user_id == $_SESSION['ses_userid'] ? 4 : ($access['daten'][$eg_id] == 4 ? 5 : $access['daten'][$eg_id]);
	}
	$list->init("daten", "ko_event_mod", array("chk", "check", "delete"), $_SESSION["show_start"], $_SESSION["show_limit"]);
	$list->disableListCheckAll();
	$list->setTitle(getLL("daten_mod_list_title")." ".getLL("daten_mod_list_title_".$mode));
	$list->setAccessRights(array('check' => 5, 'delete' => 4), $mod_access);
	$list->setActions(array("check" => array("action" => $action_check,
																					 "additional_js" => "c1=confirm('".getLL("daten_mod_confirm_confirm")."');if(!c1) return false;c = confirm('".getLL("daten_mod_confirm_confirm2")."');set_hidden_value('mod_confirm', c);"),
													"delete" => array("action" => $action_delete,
																						"additional_js" => ($access['daten']['MAX'] > 3 ? "c1 = confirm('".getLL("daten_mod_decline_confirm")."');if(!c1) return false;c = confirm('".getLL("daten_mod_decline_confirm2")."');set_hidden_value('mod_confirm', c);" : "") ))
										);
	$list->disableMultiedit();
	if($mode == "edit") $list->disableKotaProcess();

	$list->setStats($rows, 1, 500);
	$list->setSort(TRUE, "setsortevent", $_SESSION["sort_events"], $_SESSION["sort_events_order"]);

	//Footer for mod events
	$list_footer[] = array("label" => getLL("daten_list_footer_del_label"), 
												 "button" => '<input type="submit" onclick="c1 = confirm(\''.getLL("daten_mod_decline_confirm").'\');if(!c1) return false;'.($access['daten']['MAX'] > 3 ? 'c = confirm(\''.getLL("daten_mod_decline_confirm2").'\');set_hidden_value(\'mod_confirm\', c);' : '').'set_action(\''.$action_delete.'_multi\');" value="'.getLL("daten_list_footer_del_button").'" />');
	if($access['daten']['MAX'] > 3) {
		$list_footer[] = array("label" => getLL("daten_list_footer_confirm_label"),
													 "button" => '<input type="submit" onclick="c1=confirm(\''.getLL("daten_mod_confirm_confirm").'\');if(!c1) return false;c = confirm(\''.getLL("daten_mod_confirm_confirm2").'\');set_hidden_value(\'mod_confirm\', c);set_action(\''.$action_check.'_multi\');" value="'.getLL("ok").'" />');
	}
	$list->setFooter($list_footer);


	if($output) {
		$list->render($es);
	} else {
		print $list->render($es);
	}
}//ko_list_mod_events()





function ko_list_groups($method, $output=TRUE) {
	global $ko_path;
	global $access;

	if($access['daten']['MAX'] < 3) return;

	$list = new kOOL_listview();

	//Nur die erlaubten Termingruppen anzeigen
	if($access['daten']['ALL'] < 3) {
		$egs = array();
		foreach($access['daten'] as $k => $v) {
			if(!intval($k)) continue;
			if($v >= 3) $egs[] = $k;
		}
		$z_where = " AND `id` IN ('".implode("','", $egs)."') ";
	} else {
		$z_where = '';
	}

	//Limit bestimmen
  $z_limit = "LIMIT " . ($_SESSION["show_start"]-1) . ", " . $_SESSION["show_limit"];
	$rows = db_get_count("ko_eventgruppen", "id", $z_where);
	ko_get_eventgruppen($es, $z_limit, $z_where);

	//Add notify hint if set for an eventgroup
	foreach($es as $id => $g) {
		if(!$g['notify']) continue;
		$ids = array();
		foreach(explode(',', $g['notify']) as $gid) $ids[] = substr($gid, 1);
		ko_get_groups($groups, ' AND `id` IN (\''.implode("','", $ids).'\')');
		$names = '';
		foreach($groups as $group) $names .= $group['name'].', ';
		$names = substr($names, 0, -2);
		$es[$id]['name'] .= '&nbsp;<span onmouseover="tooltip.show(\''.getLL('daten_notify_hint').'<br /><b>'.$names.'</b>\');" onmouseout="tooltip.hide();"><img src="'.$ko_path.'images/comment.png" border="0" /></span>';
	}

	$list->init("daten", "ko_eventgruppen", array("chk", "edit", "delete"), $_SESSION["show_start"], $_SESSION["show_limit"]);
	$list->setTitle(getLL("daten_groups_list_title"));
	$list->setAccessRights(array('edit' => 3, 'delete' => 'ALL3'), $access['daten']);
	$list->setActions(array("edit" => array("action" => "edit_gruppe"),
													"delete" => array("action" => "delete_gruppe", "confirm" => TRUE))
										);
	$list->setStats($rows);
	$list->setSort(TRUE, "setsorteventgroups", $_SESSION["sort_tg"], $_SESSION["sort_tg_order"]);

	//Footer
	if(($method == 'all' && $access['daten']['MAX'] > 1) || ($method == 'mod' && $access['daten']['MAX'] > 3)) {
		$list_footer[] = array("label" => getLL("daten_list_footer_del_label"),
													 "button" => '<input type="submit" onclick="c=confirm('."'".getLL("daten_list_footer_del_button_confirm")."'".');if(!c) return false;set_action(\'del_selected\');" value="'.getLL("daten_list_footer_del_button").'" />');
		$list->setFooter($list_footer);
	}

	if($output) {
		$list->render($es);
	} else {
		print $list->render($es);
	}
}//ko_list_groups()





function ko_formular_termin($mode, $id, $data=array()) {
	global $smarty, $KOTA;
	global $access;

	if($mode == "edit" && $id != 0) {
		//Get event data to be edited
	  ko_get_event_by_id($id, $e);
		if($access['daten'][$e['eventgruppen_id']] < 2) return;

		if(ko_module_installed("reservation")) {
			//Set res times to event times if none are given for even group
			ko_get_eventgruppe_by_id($e["eventgruppen_id"], $tg);
			//Set res times as fallback from eventgroup or event (will be overwritten below if reservations were found)
	  	$txt_res_startzeit = ($tg["res_startzeit"] == "00:00:00") ? sql_zeit($e["startzeit"]) : sql_zeit($tg["res_startzeit"]);
	  	$txt_res_endzeit = ($tg["res_endzeit"] == "00:00:00") ? sql_zeit($e["endzeit"]) : sql_zeit($tg["res_endzeit"]);

			//Get connected reservations
			if($e["reservationen"]) {
				$do_res_values = $do_res_output = array();
				foreach(explode(",", $e["reservationen"]) as $r) {
					$res_ = "";
					$res = db_select_data("ko_reservation AS r LEFT JOIN ko_resitem AS i ON r.item_id = i.id", "WHERE r.id = '$r'", "r.*, i.name AS item_name", "", "", TRUE);
					//Ignore deleted reservations
					if(!$res["id"]) continue;

					$do_res_values[] = $res["item_id"];
					$do_res_output[] = $res["item_name"];
					//Overwrite res times with actual values from reservations
					$txt_res_startzeit = sql_zeit($res["startzeit"]);
					$txt_res_endzeit = sql_zeit($res["endzeit"]);
				}//foreach(res_s as r)
			}//if(e[reservationen])
		}//if(ko_module_installed(reservation))

	}//if(edit && id)

	else if($mode == "neu") {
		if($access['daten']['MAX'] < 2) return;

		//set values given through data[]
		$data["startzeit"] = $data["start_time"];
		$data["endzeit"] = $data["end_time"];
		kota_assign_values("ko_event", $data);
		//Zeit ber $data-Array gesetzt (z.B. aus Wochenansicht)
		if(isset($data["start_time"])) {
			$txt_res_startzeit = $data["start_time"];
		}
		if(isset($data["end_time"])) {
			$txt_res_endzeit = $data["end_time"];
		}
		
		//Refill form with submitted values
		if($_POST["submit"]) {
			$form_values = NULL;
			foreach($_POST["koi"]["ko_event"] as $col => $value) {
				if(isset($KOTA["ko_event"][$col])) {
					$form_values[$col] = $value[0];
				}
			}
			kota_assign_values("ko_event", $form_values);

			if(ko_module_installed("reservation")) {
				$txt_res_startzeit = sql_zeit($_POST["txt_res_startzeit"]);
				$txt_res_endzeit = sql_zeit($_POST["txt_res_endzeit"]);
			}
		}

	}//if(mode == "neu")
	else return;

	
	//Wiederholungs-Auswahl wieder setzen
	$true = 0;
	switch($_POST["rd_wiederholung"]) {
		case "keine": $true = 0; break;
		case "taeglich": $true = 1; break;
		case "woechentlich": $true = 2; break;
		case "monatlich1": $true = 3; break;
		case "monatlich2": $true = 4; break;
		default: $true = 0;
	}
	for($i=0; $i<5; $i++) {
		$rd_wiederholung_checked[$i] = ($true == $i) ? 'checked="checked"' : "";
	}
	$smarty->assign("rd_wiederholung_checked", $rd_wiederholung_checked);
	$txt_repeat_tag = $_POST["txt_repeat_tag"] ? format_userinput($_POST["txt_repeat_tag"], "uint") : 1;
	$txt_repeat_woche = $_POST["txt_repeat_woche"] ? format_userinput($_POST["txt_repeat_woche"], "uint") : 1;
	$txt_repeat_monat2 = $_POST["txt_repeat_monat2"] ? format_userinput($_POST["txt_repeat_monat2"], "uint") : 1;


	//Select-Inputs fr Wiederholungen abfllen (Auswahl vom letzten Mal wieder setzen
	$values = array(1, 2, 3, 4);
	$output = array("1.", "2.", "3.", "4.");
	$value = format_userinput($_POST["sel_monat1_nr"], "uint", FALSE, 1);
	$sel1_code = "";
	foreach($values as $i => $v) {
		$sel = ($value == $v) ? ' selected="selected"' : '';
		$sel1_code .= '<option value="'.$v.'"'.$sel.'>'.$output[$i].'</option>';
	}

	$values = array(1, 2, 3, 4, 5, 6, 0);
	$monday = date_find_last_monday(date("Y-m-d"));
	$output = NULL; for($i=0; $i<7; $i++) $output[] = strftime("%A", strtotime(add2date($monday, "tag", $i, TRUE)));
	$value = format_userinput($_POST["sel_monat1_tag"], "uint", FALSE, 1);
	$sel2_code = "";
	foreach($values as $i => $v) {
		$sel = ($value == $v) ? ' selected="selected"' : '';
		$sel2_code .= '<option value="'.$v.'"'.$sel.'>'.$output[$i].'</option>';
	}

	$repeat_descs[] = getLL("daten_repeat_none");
	$repeat_descs[] = sprintf(getLL("daten_repeat_daily"), ' </label><input type="text" name="txt_repeat_tag" value="'.$txt_repeat_tag.'" size="2" /> ', '<label>');
	$repeat_descs[] = sprintf(getLL("daten_repeat_weekly"), ' </label><input type="text" name="txt_repeat_woche" value="'.$txt_repeat_woche.'" size="2" /> ', '<label>');
	$repeat_descs[] = sprintf(getLL("daten_repeat_monthly1"), ' </label><select name="sel_monat1_nr" size="0">'.$sel1_code.'</select><select name="sel_monat1_tag" size="0">'.$sel2_code.'</select></label>');
	$repeat_descs[] = sprintf(getLL("daten_repeat_monthly2"), ' </label><input type="text" name="txt_repeat_monat2" value="'.$txt_repeat_monat2.'" size="2" /> ', '<label>');


	//Repeat-Stop
	$values = array(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31);
	$output = $values;
	$value = $_POST["sel_bis_tag"] ? format_userinput($_POST["sel_bis_tag"], "uint", FALSE, 2) : 31;
	$sel_day_code = "";
	foreach($values as $i => $v) {
		$sel = ($value == $v) ? ' selected="selected"' : '';
		$sel_day_code .= '<option value="'.$v.'"'.$sel.'>'.$output[$i].'</option>';
	}

	$values = array(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12);
	$jan = date("Y-m-d", mktime(1,1,1, 1, 1, 2006));
	$output = NULL; for($i=0; $i<12; $i++) $output[] = strftime("%B", strtotime(add2date($jan, "monat", $i, TRUE)));
	$value = $_POST["sel_bis_monat"] ? format_userinput($_POST["sel_bis_monat"], "uint", FALSE, 2) : strftime("%m", time());
	$sel_month_code = "";
	foreach($values as $i => $v) {
		$sel = ($value == $v) ? ' selected="selected"' : '';
		$sel_month_code .= '<option value="'.$v.'"'.$sel.'>'.$output[$i].'</option>';
	}

	$values = array((int)strftime("%Y", time()), (int)strftime("%Y", time())+1, (int)strftime("%Y", time())+2);
	$value = $_POST["sel_bis_jahr"] ? format_userinput($_POST["sel_bis_jahr"], "uint", FALSE, 4) : strftime("%Y", time());
	$sel_year_code = "";
	foreach($values as $v) {
		$sel = ($value == $v) ? ' selected="selected"' : '';
		$sel_year_code .= '<option value="'.$v.'"'.$sel.'>'.$v.'</option>';
	}

	$repeat_stop  = '<select name="sel_bis_tag" size="0">'.$sel_day_code.'</select>&nbsp;&nbsp;';
	$repeat_stop .= '<select name="sel_bis_monat" size="0">'.$sel_month_code.'</select>&nbsp;&nbsp;';
	$repeat_stop .= '<select name="sel_bis_jahr" size="0">'.$sel_year_code.'</select>';
	$repeat_stop .= '<br />'.getLL("daten_repeat_or").'<br /><input type="text" name="txt_num_repeats" size="4" maxlength="3" onkeyup="repeat_disable(this.value);" />&nbsp;'.getLL("daten_repeat_iterations");



	//Formular aufbauen
	$table = "ko_event";
	$rowcounter = 0;
	$gc = 0;

	//Spezielle Formular-Einstellungen vornehmen
	if($mode == "neu") $KOTA[$table]["eventgruppen_id"]["form"]["params"] .= ' onchange="javascript:selEventGroup(this.value);"';
	if(isset($KOTA[$table]["dp"])) $KOTA[$table]["dp"]["form"]["params"] = ($e["dp"] ? 'checked="checked"' : '');

	//Get values for room-select from ko_event and ko_eventgruppen
	$values = array_unique(array_merge(db_select_distinct("ko_event", "room", "", "", TRUE), db_select_distinct("ko_eventgruppen", "room", "", "", TRUE)));
	$KOTA[$table]["room"]["form"]["values"] = $values;
	$KOTA[$table]["room"]["form"]["descs"] = $values;
	

	//get first part of form from kota
	$group = ko_multiedit_formular($table, "", $id, "", "", TRUE);
	$group[$gc]["titel"] = "";
	$rowcounter = sizeof($group[$gc]["row"])+1;


	//Wiederholungen (nur bei Neu)
	if($mode == "neu") {
		$group[++$gc] = array("titel" => getLL("daten_repeat"), "state" => "closed", "colspan" => 'colspan="2"');
		$group[$gc]["row"][$rowcounter]["inputs"][0] = array("desc" => getLL("daten_repeat_title1"),
																 "type" => "radio",
																 "name" => "rd_wiederholung",
																 "values" => array("keine", "taeglich", "woechentlich", "monatlich1", "monatlich2"),
																 "descs" => $repeat_descs,
																 "separator" => "<br />",
																 "value" => isset($_POST["rd_wiederholung"]) ? $_POST["rd_wiederholung"] : "keine"
																 );
		$group[$gc]["row"][$rowcounter++]["inputs"][1] = array("desc" => getLL("daten_repeat_title2"),
																 "type" => "html",
																 "value" => $repeat_stop
																 );
	}

	//Reservationen
	if(ko_module_installed("reservation")) {
		//Prepare dynsoubleselect for res items
		kota_ko_reservation_item_id_dynselect($values, $descs, 2);
		$tpl_res_values = $tpl_res_descs = array();
		foreach($values as $vid => $value) {
			$tpl_res_values[] = $vid;
			$suffix = is_array($value) ? "-->" : "";
			$tpl_res_descs[] = $descs[$vid].$suffix;
		}

		//Add inputs for resitems and res_[start|stop]time
		$group[++$gc]["row"][$rowcounter++]["inputs"][0] = array("type" => "   ");
		$group[$gc]["row"][$rowcounter++]["inputs"][0] = array("desc" => getLL("daten_linked_reservations"),
																 "type" => "doubleselect",
		  													 "js_func_add" => "resgroup_doubleselect_add",
																 "name" => "sel_do_res",
																 "values" => $tpl_res_values,
																 "descs" => $tpl_res_descs,
																 "avalues" => $do_res_values,
																 "avalue" => implode(",", $do_res_values),
																 "adescs" => $do_res_output,
																 "params" => 'size="7"',
																 "colspan" => 'colspan="2"'
																 );
		$group[$gc]["row"][$rowcounter]["inputs"][0] = array("desc" => getLL("daten_linked_reservations_start"),
																 "type" => "text",
																 "name" => "txt_res_startzeit",
																 "value" => $txt_res_startzeit,
																 "params" => 'size="11" maxlength="11"'
																 );
		$group[$gc]["row"][$rowcounter++]["inputs"][1] = array("desc" => getLL("daten_linked_reservations_stop"),
																 "type" => "text",
																 "name" => "txt_res_endzeit",
																 "value" => $txt_res_endzeit,
																 "params" => 'size="11" maxlength="11"'
																 );
	}


	$smarty->assign("tpl_titel", ( ($mode == "neu") ? getLL("daten_new_event") : getLL("daten_edit_event")) );
	$smarty->assign("tpl_submit_value", getLL("save"));
	$smarty->assign("tpl_id", $id);
	$smarty->assign("tpl_action", ( ($mode == "neu") ? "submit_neuer_termin" : "submit_edit_termin") );
	//Add button "save as new"
	if($mode == 'edit') {
		$smarty->assign("tpl_submit_as_new", getLL('daten_submit_as_new'));
		$smarty->assign("tpl_action_as_new", "submit_neuer_termin");
	}
	$cancel = $_SESSION['show_back'] ? $_SESSION['show_back'] : ko_get_userpref($_SESSION["ses_userid"], "default_view_daten");
	if(!$cancel) $cancel = "show_cal_monat";
	$smarty->assign("tpl_cancel", $cancel);
	$smarty->assign("tpl_groups", $group);

	$smarty->assign("help", ko_get_help("daten", "form_neuer_termin"));

	$smarty->display("ko_formular.tpl");
}//ko_formular_termin()





function ko_formular_termingruppe($mode, $id=0) {
	global $smarty, $KOTA;
	global $access;

	if($access['daten']['MAX'] < 3) return;

	if($mode == "edit" && $id != 0) {
		//ok
	} else if($mode == "neu") {
		$id = 0;
	}//if(mode == "neu")
	else return;

	//Get values for room-select from ko_event and ko_eventgruppen
	$values = array_unique(array_merge(db_select_distinct("ko_event", "room", "", "", TRUE), db_select_distinct("ko_eventgruppen", "room", "", "", TRUE)));
	$KOTA["ko_eventgruppen"]["room"]["form"]["values"] = $values;
	$KOTA["ko_eventgruppen"]["room"]["form"]["descs"] = $values;
	
	$form_data["title"] = $mode == "neu" ? getLL("daten_new_eventgroup") : getLL("daten_edit_eventgroup");
  $form_data["submit_value"] = getLL("save");
  $form_data["action"] = $mode == "neu" ? "submit_neue_gruppe" : "submit_edit_gruppe";
  $form_data["cancel"] = "show_all_groups";

	ko_multiedit_formular("ko_eventgruppen", "", $id, "", $form_data);
}//ko_formular_termingruppe()




/**
  * Displays settings for the events
	*/
function ko_daten_settings() {
	global $smarty;
	global $access;

	if($access['daten']['MAX'] < 4) return FALSE;

	//build form
	$gc = 0;
	$rowcounter = 0;
	$value = ko_get_setting("daten_pdf_show_time");
	$frmgroup[$gc]["row"][$rowcounter]["inputs"][0] = array("desc" => getLL("daten_settings_pdf_show_time"),
			"type" => "select",
			"name" => "sel_pdf_show_time",
			'values' => array('2', '1', '0'),
			'descs' => array(getLL('daten_settings_pdf_show_time_2'), getLL('daten_settings_pdf_show_time_1'), getLL('no')),
			"value" => $value,
			);
	$value = ko_get_setting("daten_pdf_show_comment");
	$frmgroup[$gc]["row"][$rowcounter++]["inputs"][1] = array("desc" => getLL("daten_settings_pdf_show_comment"),
			"type" => "select",
			"name" => "sel_pdf_show_comment",
			"values" => array("1", "0"),
			"descs" => array(getLL("yes"), getLL("no")),
			"value" => $value,
			);
	$value = ko_get_setting('daten_pdf_week_start');
	$monday = date_find_last_monday(date('Y-m-d'));
	$daynames[] = strftime('%A', strtotime($monday));
	for($i=1; $i<7; $i++) {
		$daynames[] = strftime('%A', strtotime(add2date($monday, 'tag', $i, TRUE)));
	}
	$frmgroup[$gc]['row'][$rowcounter++]['inputs'][0] = array('desc' => getLL('daten_settings_pdf_week_start'),
			'type' => 'select',
			'name' => 'sel_pdf_week_start',
			'values' => array(1,2,3,4,5,6,0),
			'descs' => $daynames,
			'value' => $value,
			);
	$value = ko_get_setting("daten_mark_sunday");
	$frmgroup[$gc]["row"][$rowcounter++]["inputs"][0] = array("desc" => getLL("daten_settings_mark_sunday"),
			"type" => "select",
			"name" => "sel_mark_sunday",
			"values" => array("1", "0"),
			"descs" => array(getLL("yes"), getLL("no")),
			"value" => $value,
			);
	$value = ko_get_setting("daten_monthly_title");
	$frmgroup[$gc]["row"][$rowcounter]["inputs"][0] = array("desc" => getLL("daten_settings_monthly_title"),
			"type" => "select",
			"name" => "sel_monthly_title",
			"values" => array("eventgruppen_id", "kommentar", 'both'),
			"descs" => array(getLL("kota_ko_event_eventgruppen_id"), getLL("kota_ko_event_kommentar"), getLL('both')),
			"value" => $value,
			);
	$value = ko_html(ko_get_setting("daten_title_length"));
	$frmgroup[$gc]["row"][$rowcounter++]["inputs"][1] = array("desc" => getLL("daten_settings_title_length"),
			"type" => "text",
			"name" => "txt_title_length",
			"value" => $value,
			"params" => 'size="10"',
			);

	//display the form
	$smarty->assign("tpl_titel", getLL("daten_settings_form_title"));
	$smarty->assign("tpl_submit_value", getLL("save"));
	$smarty->assign("tpl_action", "submit_daten_settings");
	$cancel = ko_get_userpref($_SESSION["ses_userid"], "default_view_daten");
	if(!$cancel) $cancel = "show_cal_monat";
	$smarty->assign("tpl_cancel", $cancel);
	$smarty->assign("tpl_groups", $frmgroup);
	$smarty->assign("help", ko_get_help("daten", "daten_settings"));

	$smarty->display('ko_formular.tpl');
}//ko_daten_settings()





function check_daten_entries(&$data) {
	ko_get_eventgruppe_by_id($data["eventgruppen_id"], $eventgroup);
	if(!$eventgroup["name"]) return 8;

	//Datumsformat berprfen
  if(!check_datum($data["startdatum"])) return 1;

  if($data["enddatum"] != "") {
		if(!check_datum($data["enddatum"])) return 1;
		//Events longer than a day without endtime must be all day events
		if($data["enddatum"] != $data["startdatum"] && ($data["endzeit"] == "" || !check_zeit($data["endzeit"])) ) {
			$data["startzeit"] = $data["endzeit"] = "";
		}

		//Startdatum < Enddatum
		$date_s = explode(".", $data["startdatum"]);
		$date_e = explode(".", $data["enddatum"]);
		if( (int)($date_s[2] . str_to_2($date_s[1]) . str_to_2($date_s[0])) > (int)($date_e[2] . str_to_2($date_e[1]) . str_to_2($date_e[0])) ) return 4;
	}//if(data["enddatum"] != "")

	//Zeit berprfen
  if(trim($data["startzeit"]) == "" || !check_zeit($data["startzeit"])) {
		//if first time is empty, set second one empty as well (all day event)
		$data["endzeit"] = "";
	} else {
		if($data["endzeit"] != "") {
			if(!check_zeit($data["endzeit"])) return 2;
			//Bei eintgigem Anlass muss die Endzeit grsser sein als die Startzeit
			$time_s1 = str_replace(":", "", $data["startzeit"]);
			$time_s2 = str_replace(":", "", $data["endzeit"]);
			if((trim($data["enddatum"]) == "" || $data["startdatum"] == $data["enddatum"]) && (int)$time_s1 > (int)$time_s2) return 2;
		}
	}

	return 0;
}//check_daten_entries()





/**
  * Display the calendar div which will be filled by fullCalendar JS
	*/
function ko_daten_calendar() {
	global $ko_path;

	//Add the link to the year view
	$code  = '';
	$code .= '<div id="ko_calendar">';
	$code .= '<div class="fc-mwselect">';
	$code .= '<div name="mwselect" id="mwselect" style="float: left;">';
	$code .= ko_calendar_mwselect($_SESSION['cal_view']);
	$code .= '</div>';
	$code .= '<a href="index.php?action=show_cal_jahr"><img src="'.$ko_path.'images/cal_jahr.gif" border="0" title="'.getLL('daten_cal_year').'"></a>';
	$code .= '</div>';
	$code .= '</div>';

	//Add PDF link
	$code .= '<table style="margin-left:12px" cellspacing="0" cellpadding="3">';
	$code .= '<tr><td style="border-left-style:solid;border-left-width:1px">&nbsp;</td></tr>';
	$code .= '<tr><td style="border-left-style:solid;border-left-width:1px;border-bottom-width:1px;border-bottom-style:solid;">';
	$code .= '<span onclick="sendReq(\'inc/ajax.php\', \'action\', \'pdfcalendar\', do_element);">';
	$code .= '<img src="'.$ko_path.'images/create_pdf.png" border="0" />&nbsp;'.getLL("res_list_footer_pdf_label").'</span>';
	$code .= '<span name="daten_pdf_link" id="daten_pdf_link">&nbsp;</span>';
	$code .= '</td></tr>';
	$code .= '</table>';

	print $code;
}//ko_daten_calendar()







function ko_daten_cal_woche($woche, $jahr, $mode="html", $output=TRUE) {
	global $smarty, $ko_path;
	global $access;

	if($access['daten']['MAX'] < 1) return FALSE;

	//Find beginning and end date of selected week
	$start = add2date("01.01.$jahr", "tag", (7*($woche-1)));
	$week_start = ko_get_setting('daten_pdf_week_start');
	$inc = -1; $back = 0;
	while((int)strftime("%w", mktime(1,1,1, $start[1], $start[0], $start[2])) != $week_start) {
		$start = add2date(implode(".", $start), "tag", $inc);
		$back++;
		if($back > 2) $inc = 1;
	}
	$ende = add2date(implode(".", $start), "tag", 6);

	apply_daten_filter($z_where, $z_limit, "immer", "immer");  //in Kalenderansicht Zeit-Filter nicht anwenden

	$smarty->assign("tpl_cal_titel", getLL("time_week")." ".strftime("%V", mktime(1, 1, 1, $start[1], $start[0], $start[2])));

	//Heute
	get_heute($h_tag, $h_monat, $h_jahr);
	$h_week = strftime("%V", mktime(1,1,1, $h_monat, $h_tag, $h_jahr));

	$w_prev = add2date(implode(".", $start), "tag", -7);
	$prev_week = strftime("%V", mktime(1,1,1, $w_prev[1], $w_prev[0], $w_prev[2]));
	$prev_year = strftime("%G", mktime(1,1,1, $w_prev[1], $w_prev[0], $w_prev[2]));
	$w_next = add2date(implode(".", $start), "tag", 7);
	$next_week = strftime("%V", mktime(1,1,1, $w_next[1], $w_next[0], $w_next[2]));
	$next_year = strftime("%G", mktime(1,1,1, $w_next[1], $w_next[0], $w_next[2]));

	$tpl_prev_link = "javascript:sendReq('../daten/inc/ajax.php', 'action,set_week,set_year,sesid', 'setwoche,$prev_week,$prev_year,".session_id()."', do_element);";
	$tpl_next_link = "javascript:sendReq('../daten/inc/ajax.php', 'action,set_week,set_year,sesid', 'setwoche,$next_week,$next_year,".session_id()."', do_element);";
	$tpl_today_link = "javascript:sendReq('../daten/inc/ajax.php', 'action,set_week,set_year,sesid', 'setwoche,$h_week,$h_jahr,".session_id()."', do_element);";
	$smarty->assign("tpl_prev_link", $tpl_prev_link);
	$smarty->assign("tpl_next_link", $tpl_next_link);
	$smarty->assign("tpl_today_link", $tpl_today_link);

	//Herausfinden, ob neue Termine angelegt werden drfen
	$set_new_date = FALSE;

	$hour_start = ko_get_setting("cal_woche_start");
	$hour_end = ko_get_setting("cal_woche_end");
	for($h = $hour_start; $h < $hour_end; $h++) {
		$hour[$h]["name"] = str_to_2($h)."-".str_to_2($h+1);
	}

	for($t_inc = 0; $t_inc < 7; $t_inc++) {
		$tag = add2date(implode(".", array($start[0], $start[1], $start[2])), "tag", $t_inc);
		$tag_str = implode(".", $tag);
		$col[$t_inc] = 0;

		//Datum setzen
		$daynames[$t_inc] = strftime("%A<br />".$GLOBALS["DATETIME"]["dmY"], mktime(1,1,1, $tag[1], $tag[0], $tag[2]));

		//new_date nur setzen, falls mindestens fr eine Termingruppe neue Termine angelegt werden drfen
		if($set_new_date) $new_date = $tag_str;

		//Alle Termine an diesem Tag finden
		ko_get_events_by_date($tag[0], $tag[1], $tag[2], $r_, $z_where);

		if(sizeof($r_) > 0) {
			foreach($r_ as $r_i => $r) {
				$color = ko_get_eventgruppen_farbe($r["eventgruppen_id"]);

				//Termin-Beschreibung
				$desc = "&lt;b&gt;".ko_html2($gruppen[$r["eventgruppen_id"]]["name"])."&lt;/b&gt;&lt;br /&gt;";
				$desc .= $r["room"] ? "<i>".getLL("daten_location").": ".ko_html2($r["room"])."</i><br />":"";
				if($r["startzeit"] == "00:00:00" && $r["endzeit"] == "00:00:00") {
					$desc .= getLL("time_all_day");
				} else if($r["startdatum"] != $r["enddatum"]) {  //Mehrtgige Termine
					if($tag[0] == substr($r["startdatum"], 8, 2) && $tag[1] == substr($r["startdatum"], 5, 2))
						$desc .= getLL("time_from")." ".substr($r["startzeit"], 0, -3);
					else if($tag[0] == substr($r["enddatum"], 8, 2) && $tag[1] == substr($r["enddatum"], 5, 2))
						$desc .= getLL("time_to")." ".substr($r["endzeit"], 0, -3);
					else
						$desc .= getLL("time_all_day");
				} else {  //eintgig
					$desc .= substr($r["startzeit"], 0, -3) . (($r["endzeit"]!="00:00:00") ? ("-" . substr($r["endzeit"], 0, -3)) : "");
				}
				$desc .= ": ".ko_html($r["kommentar"]);

				//shortname
				$shortname = ko_html($gruppen[$r["eventgruppen_id"]]["shortname"]);

				//Anfangs- und Endstunden des Anlasses finden (als Dezimalbruch)
				if($r["startzeit"] == "00:00:00" && $r["endzeit"] == "00:00:00") {
					$h1 = "00";
					$h2 = "24";
				} else {
					$h1 = (substr($r["startdatum"], -2) != $tag[0]) ? $hour_start : ((int)substr($r["startzeit"], 0, 2) + ((int)substr($r["startzeit"], 3, 2)/60));
					$h2 = (substr($r["enddatum"], -2) != $tag[0]) ? $hour_end : ((int)substr($r["endzeit"], 0, 2) + ((int)substr($r["endzeit"], 3, 2)/60));
				}
				$first = TRUE;
				while($h1 < $hour_start) $h1++;
				while($h1 < $h2 && $h1 < $hour_end) {
					if(($h1+1) >= $h2 || ($h1+1) >= $hour_end) $last = TRUE;
					else $last = FALSE;

					$click = '';
					$del_link = '';

					$hour[$h1]["day"][$t_inc]["cols"][$col[$t_inc]] = array("color" => $color,
																																	"first" => $first,
																																	"last" => $last,
																																	"desc" => $desc,
																																	"shortname" => $shortname,
																																	"click" => $click,
																																	"del_link" => $del_link,
																																	"mod" => FALSE,
																																	"check_link" => '',
																																	"id" => $r["id"],
																																	"item_id" => $r["eventgruppen_id"],
																																	);
					$h1++;
					$first = FALSE;
				}
				$col[$t_inc]++;
			}//foreach(r_ as r)
		}//if(sizeof(r_))

		for($h = $hour_start; $h < $hour_end; $h++) {
			$hour_stamp = mktime($h, 0, 0, $tag[1], $tag[0], $tag[2]);

			if(is_array($hour[$h]["day"][$t_inc]["cols"])) {
				$hour[$h]["day"][$t_inc]["col_width"] = 100/(int)$col[$t_inc]."%";
				for($i=0; $i<$col[$t_inc]; $i++) {
					if(!is_array($hour[$h]["day"][$t_inc]["cols"][$i])) {
						$hour[$h]["day"][$t_inc]["cols"][$i] = array("desc" => "");
						//Heute definieren
						if((int)$tag[0] == (int)$h_tag && (int)$tag[1] == (int)$h_monat && (int)$tag[2] == (int)$h_jahr) $hour[$h]["day"][$t_inc]["heute"] = TRUE;
						else $hour[$h]["day"][$t_inc]["heute"] = FALSE;
					}
				}
				ksort($hour[$h]["day"][$t_inc]["cols"]);
			}
			else {
				//Heute definieren
				if((int)$tag[0] == (int)$h_tag && (int)$tag[1] == (int)$h_monat && (int)$tag[2] == (int)$h_jahr) $hour[$h]["day"][$t_inc]["heute"] = TRUE;
				else $hour[$h]["day"][$t_inc]["heute"] = FALSE;

				$hour[$h]["day"][$t_inc]["col_width"] = "100%";
				$hour[$h]["day"][$t_inc]["empty"] = TRUE;
				if($set_new_date) {
					$hour[$h]["day"][$t_inc]["mouseup"] = "jumpToUrl('?action=neuer_termin&amp;end_stamp=$hour_stamp&amp;start_stamp='+document.getElementsByName('new_event_start')[0].value);";
					$hour[$h]["day"][$t_inc]["mousedown"] = "set_hidden_value('new_event_start', '$hour_stamp');";
				}//if(set_new_date)
			}
		}//for(h=hour_start..hour_end)
	}//for(t_inc=0..6)

	if($mode == "html") {
		//Footer
		//PDF-Export-Link anzeigen:
		$button_code .= '&nbsp;<span onclick="sendReq(\'../daten/inc/ajax.php\', \'action,sesid\', \'datenpdfweek,'.session_id().'\', do_element);">';
		$button_code .= '<img src="'.$ko_path.'images/create_pdf.png" border="0" />&nbsp;'.getLL("res_list_footer_pdf_label").'</span>';
		$button_code .= '<span name="daten_pdf_link" id="daten_pdf_link">&nbsp;</span>';
		$list_footer[] = array("label" => "", "button" => $button_code);
		$smarty->assign("show_list_footer", TRUE);
		$smarty->assign("list_footer", $list_footer);

		$smarty->assign("daynames", $daynames);
		$smarty->assign("show_birthday", $_SESSION["show_birthdays"] && ko_module_installed("leute"));
		$smarty->assign("birthday", $birthday);
		$smarty->assign("hour", $hour);

		//LL-Values
		$smarty->assign("label_cal_year", getLL("daten_cal_year"));
		$smarty->assign("label_cal_month", getLL("daten_cal_month"));
		$smarty->assign("label_cal_week", getLL("daten_cal_week"));
		$smarty->assign("label_today", getLL("time_today"));
		$smarty->assign("label_delete", getLL("delete"));
		$smarty->assign("label_time", getLL("daten_time"));
	
		if($output) {
			$smarty->display('ko_cal_woche_gross.tpl');
		} else {
			print $smarty->fetch('ko_cal_woche_gross.tpl');
		}
	} else if($mode == "pdf") {
		//Legende vorbereiten
		ko_get_eventgruppen($gruppen); $legende = array("titel" => getLL("daten_events"));
		foreach($_SESSION["show_tg"] as $s) {
			if($gruppen[$s]["name"] && $access['daten'][$s] > 0) {
				$legende[$s] = array("color" => ko_get_eventgruppen_farbe($s), "name" => $gruppen[$s]["name"]);
			}
		}

		//PDF erstellen
		$filename = getLL("daten_filename_pdf").str_to_2($woche)."_".$jahr."_".strftime("%d%m%Y_%H%M%S", time()).".pdf";
		$title = str_to_2($woche).'-'.$jahr;
		ko_export_cal_pdf_week($filename, $daynames, $hour, $legende, $title);
		return $filename;
	}
}//ko_daten_cal_woche()




function ko_daten_cal_jahr($num=6, $start=1, $output=TRUE) {
	global $smarty, $ko_path;
	global $access;

	//Heute
	get_heute($h_tag, $h_monat, $h_jahr);
	$j = $_SESSION["cal_jahr_jahr"] ? $_SESSION["cal_jahr_jahr"] : $h_jahr;
	$t = 1;
	$m = $start;
	unset($day);

	//Monate
	unset($cal_month);
	for($i = $start; $i < ($start+$num); $i++) {
		$ii = $i > 12 ? ($i-12) : $i;
		$jj = ($ii != $i) ? ($j+1) : $j;
		$cal_month[] = array("code" => (str_to_2($ii)."-".$jj), "name" => strftime("%B", mktime(1,1,1, $i, 1, $j)));
	}
	$next = add2date("$t.$m.$j", "monat", $num);
	$prev = add2date("$t.$m.$j", "monat", "-$num");
	$today_start = 1;
  while( ((int)$today_start+$num-1) < $h_monat) {
    $today_start += $num;
  }

	$end_code = $next[2].str_to_2($next[1]).str_to_2($next[0]);

	$tpl_prev_link = "javascript:sendReq('../daten/inc/ajax.php', 'action,set_year,set_start,sesid', 'setjahr,".$prev[2].",".(int)$prev[1].",".session_id()."', do_element);";
	$tpl_next_link = "javascript:sendReq('../daten/inc/ajax.php', 'action,set_year,set_start,sesid', 'setjahr,".$next[2].",".(int)$next[1].",".session_id()."', do_element);";
	$tpl_today_link = "javascript:sendReq('../daten/inc/ajax.php', 'action,set_year,set_start,sesid', 'setjahr,$h_jahr,$today_start,".session_id()."', do_element);";
	

	$smarty->assign("tpl_cal_month", $cal_month);
	$smarty->assign("tpl_cal_month_width", (int)(90/$num));
	$smarty->assign("tpl_cal_titel", strftime("%Y", mktime(1,1,1, 1,1,$j)));

	$smarty->assign("tpl_prev_link", $tpl_prev_link);
	$smarty->assign("tpl_next_link", $tpl_next_link);
	$smarty->assign("tpl_today_link", $tpl_today_link);


	//Termingruppen-Namen
	ko_get_eventgruppen($gruppen);
	foreach($gruppen as $g_i => $g) {
		if($access['daten'][$g_i] < 1 || !in_array($g_i, $_SESSION["show_tg"])) {
      unset($gruppen[$g_i]);
      continue;
    }
		$day[$g_i]["name"] = ko_html($g["name"]);
		$day[$g_i]["tip"] = ko_html2($g["name"]);
	}

	//Permanente Filter anwenden
	$z_where = "";
	$perm_filter_start = ko_get_setting("daten_perm_filter_start");
	$perm_filter_ende  = ko_get_setting("daten_perm_filter_ende");
	if($access['daten']['MAX'] < 2) {
		if($perm_filter_start != "") {
			$z_where .= " AND startdatum >= '".$perm_filter_start."' ";
		}
		if($perm_filter_ende != "") {
			$z_where .= " AND startdatum <= '".$perm_filter_ende."' ";
		}
	}

	//Termine einfllen
	$day_code = $j.str_to_2($m).str_to_2($t);
	while($day_code < $end_code) {
		//Wochentag vorausfllen
		$wt = strftime("%w", mktime(1,1,1, $m, $t, $j));
		if($wt == 0) $style = "background:#cccccc;";
		else if($wt == 6) $style = "background:#dddddd;";
		else $style = "";
		foreach($gruppen as $g_i => $g) {
			$day[(int)$g_i]["events"][$m]["days"][$t]["style"] = $style;
		}
		
		//Termine einfllen
		ko_get_events_by_date($t, $m, $j, $dates, $z_where);
		if(sizeof($dates) > 0) {
			foreach($gruppen as $g_i => $g) {
				$day_text = "";
				foreach($dates as $date) {
					if((int)$date["eventgruppen_id"] == (int)$g_i) {

						$desc = "";
						if($date["startzeit"] == "00:00:00" && $date["endzeit"] == "00:00:00") {
							$desc .= getLL("time_all_day");
						}
						else if($date["startdatum"] != $date["enddatum"]) {  //Mehrtgige Termine
							if($t == substr($date["startdatum"], 8, 2) && $m == substr($date["startdatum"], 5, 2))
								$desc .= getLL("time_from")." ".substr($date["startzeit"], 0, -3);
							else if($t == substr($date["enddatum"], 8, 2) && $m == substr($date["enddatum"], 5, 2))
								$desc .= getLL("time_to")." ".substr($date["endzeit"], 0, -3);
							else
								$desc .= getLL("time_all_day");
						} else {  //eintgig
							$desc .= ($date["startzeit"] != "00:00:00" ? substr($date["startzeit"], 0, -3) : "") . (($date["endzeit"] != "00:00:00") ? ("-" . substr($date["endzeit"], 0, -3)) : "");
						}
						$day_text .= ($desc != "") ? "<br /><b>- ".$desc."</b>" : "<br />";

						$day_text .= $date["kommentar"] ? ": &quot;".ko_html2($date["kommentar"]).'&quot;' : "";
					}
				}//foreach(dates)

				if($day_text) {
					$day[(int)$g_i]["events"][$m]["days"][$t]["tip"]  = "<b>".strftime("%A, %d. %B %Y", mktime(1,1,1, $m,$t,$j))."</b><br />".ko_html2($g["name"]);
					$day[(int)$g_i]["events"][$m]["days"][$t]["tip"] .= $day_text;
					$day[(int)$g_i]["events"][$m]["days"][$t]["style"] = "background:#".($g["farbe"] ? $g["farbe"] : "999999");
				}
			}//foreach(gruppen)
		}
		unset($dates);

		//Tag inkrementieren
		$datum = add2date("$t.$m.$j", "tag", 1);
		$t = (int)$datum[0];
		$m = (int)$datum[1];
		$j = (int)$datum[2];
		$day_code = $j.str_to_2($m).str_to_2($t);
	}//while(day_code < end_code)

	//LL-Values
	$smarty->assign("label_cal_year", getLL("daten_cal_year"));
	$smarty->assign("label_cal_month", getLL("daten_cal_month"));
	$smarty->assign("label_cal_week", getLL("daten_cal_week"));
	$smarty->assign("label_item", getLL("daten_cal_event"));
	$smarty->assign("label_today", getLL("time_today"));

	$smarty->assign("tpl_day", $day);

	//PDF-Export-Link anzeigen:
	$button_code .= '&nbsp;<span onclick="sendReq(\'../daten/inc/ajax.php\', \'action\', \'pdfcalendar\', do_element);">';
	$button_code .= '<img src="'.$ko_path.'images/create_pdf.png" border="0" />&nbsp;'.getLL("res_list_footer_pdf_label").'</span>';
	$button_code .= '<span name="daten_pdf_link" id="daten_pdf_link">&nbsp;</span>';
	$list_footer[] = array("label" => "", "button" => $button_code);
	$smarty->assign("show_list_footer", TRUE);
	$smarty->assign("list_footer", $list_footer);

	if($output) {
		$smarty->display('ko_cal_jahr.tpl');
	} else {
		print $smarty->fetch('ko_cal_jahr.tpl');
	}
}//ko_daten_cal_jahr()






function ko_pdf_daten_render_html($layout_id) {
	global $smarty;
	global $access;

	if($access['daten']['MAX'] < 4) return false;

	ko_get_pdf_daten_layout($layout_, $layout_id);
	$layout = $layout_[$layout_id];
	$smarty->assign("layout_id", $layout_id);


	//*** Allgemeine Infos ***:
	$smarty->assign("tpl_layout_title", ko_html($layout["name"]));
	$smarty->assign("tpl_layout_desc", ko_html($layout["description"]));
	$smarty->assign("all_date_selected1", date("mY"));
	$smarty->assign("all_date_selected2", date("mY"));



	//*** Kopfzeile ***:
	$header_output = $header_value = array();
	$rows = db_select_data("ko_pdf_daten_settings", "WHERE `type`='header'");
	foreach($rows as $row) {
		$header_output[] = $row["value"];
		$header_values[] = $row["key"];
	}
	$smarty->assign("tpl_header_values", $header_values);
	$smarty->assign("tpl_header_output", $header_output);

	if($layout["header_id"]) {
		$smarty->assign("tpl_header_selected", $layout["header_id"]);
		$smarty->assign("tpl_header_checked", 'checked="checked"');
		//Titel
		$smarty->assign("txt_header_title", ko_html(ko_get_pdf_daten_setting("header_title", $layout["header_id"])));
	} else {
		$smarty->assign("tpl_header_checked", "");
		$smarty->assign("txt_header_title", "");
	}




	//*** Fusszeile ***:
	$footer_output = $footer_value = array();
	$rows = db_select_data("ko_pdf_daten_settings", "WHERE `type`='footer'");
	foreach($rows as $row) {
		$footer_output[] = $row["value"];
		$footer_values[] = $row["key"];
	}
	$smarty->assign("tpl_footer_values", $footer_values);
	$smarty->assign("tpl_footer_output", $footer_output);

	if($layout["footer_id"] > 0) {
		$smarty->assign("tpl_footer_selected", $layout["footer_id"]);
		$smarty->assign("tpl_footer_checked", 'checked="checked"');
	} else {
		$smarty->assign("tpl_footer_checked", "");
	}







	//*** Inhalt ***:

	//Gruppen-Select fllen
	//Aber nur die Gruppen, die in diesem Layout nicht schon vorkommen, damit keine doppelt eingefgt werden kann
	ko_get_pdf_daten_group($all_groups);
	$groups_in_layout = explode(",", $layout["groups"]);
	$gruppen_values = $gruppen_output = array();
	foreach($all_groups as $ag) {
		if(!in_array($ag["id"], $groups_in_layout)) {
			$gruppen_values[] = $ag["id"];
			$gruppen_output[] = $ag["name"];
		}
	}
	//Gruppen-Select nur anzeigen, wenn es noch Gruppen gibt, die in diesem Layout noch nicht vorkommen
	if(sizeof($gruppen_values) > 0) {
		$smarty->assign("gruppen_values", $gruppen_values);
		$smarty->assign("gruppen_output", $gruppen_output);
		$smarty->assign("show_groups_new", TRUE);
	} else {
		$smarty->assign("show_groups_new", FALSE);
	}

	//Layout-Select fllen
	$group_layout_output = $group_layout_values = array();
	$rows = db_select_data("ko_pdf_daten_settings", "WHERE `type`='group_layout'");
	foreach($rows as $row) {
		$group_layout_output[] = $row["value"];
		$group_layout_values[] = $row["key"];
	}
	$smarty->assign("group_layout_values", $group_layout_values);
	$smarty->assign("group_layout_output", $group_layout_output);


	//Termingruppen-Select (Nur die erlaubten anzeigen
	ko_get_eventgruppen($eventgruppen);
	foreach($eventgruppen as $eg_i => $eg) {
		if($access['daten'][$eg_i] > 3) {
			$tg_values[] = $eg_i;
			if(strlen($eg["name"]) > ITEMLIST_LENGTH_MAX) 
				$tg_output[] = substr($eg["name"], 0, ITEMLIST_LENGTH_MAX)."...";
			else 
				$tg_output[] = $eg["name"];
		}//if(group_mod)
	}
	$smarty->assign("tg_values", $tg_values);
	$smarty->assign("tg_output", $tg_output);

	//Date-Select
	$date_values = $date_output = array();
	get_heute($tag, $monat, $jahr);
	addmonth($monat, $jahr, -6);
	for($i=-6; $i<12; $i++) {
		$date_values[] = str_to_2($monat) . $jahr;
		$date_output[] = $monat . "-" . $jahr;
		addmonth($monat, $jahr, 1);
	}
	$smarty->assign("date_values", $date_values);
	$smarty->assign("date_output", $date_output);
	

	//Alle mglichen Content-Elemente
	$content_elements_all = array(1,2,3,5);

	//Content-Gruppen nur anzeigen, wenn es auch welche anzuzeigen gibt.
	if($layout["groups"] != "") {
		ko_get_eventgruppen($eventgruppen);
		$content_groups = explode(",", $layout["groups"]);
		$group_counter = 0;
		foreach($content_groups as $g) {
			ko_get_pdf_daten_group($group_, $g);
			$group = $group_[$g];
			$tpl_group[$group_counter]["id"] = $group["id"];
			$tpl_group[$group_counter]["name"] = ko_html($group["name"]);
			$tpl_group[$group_counter]["title"] = ko_html($group["title"]);
			$tpl_group[$group_counter]["layout_selected"] = $group["layout_id"];
			$group_content = explode(",", $group["content"]);
			
			$content = array();
			$content_elements = array();
			foreach($group_content as $gc_i => $gc) {
				$content[$gc_i]["type"] = $gc;
				$content_elements[] = $gc;
				switch($gc) {
					case "1":  //Text 1
						$content[$gc_i]["value"] = ko_html($group["text_1"]);
					break;
					case "2":  //Text 2
						$content[$gc_i]["value"] = ko_html($group["text_2"]);
					break;
					case "3":  //Text 3
						$content[$gc_i]["value"] = ko_html($group["text_3"]);
					break;
					case "5":  //Daten einfgen
						$z_where = "";
						
						//Termingruppen
						if($group["tgs"]) {
							$tgs = explode(",", $group["tgs"]);
							$z_where .= " AND (";
							foreach($tgs as $t) {
								if(!$t) continue;
								$z_where .= " `eventgruppen_id` = '$t' OR";
							}
							$z_where = substr($z_where,0,-3) . ") ";
						} else {  //Keine Termingruppen --> FALSE-Bedingung
							$z_where = " AND 1=2 ";
						}

						//Datum
						$dates = explode("-", $group["date"]);
						$tpl_group[$group_counter]["date_selected1"] = $dates[0];
						$tpl_group[$group_counter]["date_selected2"] = $dates[1];
						$startdate = $dates[0] != "" ? (substr($dates[0],2)."-".substr($dates[0],0,2)."-01") : strftime("%Y-%m-%d", time());
						$enddate   = $dates[1] != "" ? (substr($dates[1],2)."-".substr($dates[1],0,2)."-31") : strftime("%Y-%m-%d", time());
						$z_where .= " AND (`startdatum` >= '$startdate' AND `enddatum` <= '$enddate')";
						ko_get_events($events, $z_where);
				
						$e_counter = 0;
						$content[$gc_i]["chk_name"] = "chk_exclude".$g;
						foreach($events as $e_i => $e) {
							$content[$gc_i]["chk_ids"][$e_counter] = $e_i;
							$content[$gc_i]["chk_output"][$e_counter] = ko_html($e["eventgruppen_name"]).", ".sql2datum($e["startdatum"]).", ".substr($e["startzeit"],0,-3);

							//Exclude-Anlsse nicht ankreuzen, aber doch ausgeben
							$exclude_id = $group["exclude"];
							if($exclude_id) {
								$exclude_ids = explode(",", $exclude_id);
								if(!in_array($e_i, $exclude_ids))
									$content[$gc_i]["chk_checked"][$e_counter] = $e_i;
							} else {  //Exclude ist leer --> alle anzeigen
								$content[$gc_i]["chk_checked"][$e_counter] = $e_i;
							}

							$e_counter++;
						}

					break; //5 (Daten)

				}//switch(gc)

			}//foreach(group_content)

			//Content-Elemente mit denen ergnzen, die nicht verwendet werden. Denn diese sollen doch auch aktivierbar sein.
			$content_diff = array_diff($content_elements_all, $content_elements);
			$counter = sizeof($content_elements);
			foreach($content_diff as $c) {
				$content[$counter]["type"] = $c."n";
				$content[$counter++]["value"] = "";
			}


			$tpl_group[$group_counter]["content"] = $content;
			$group_counter++;
		}//foreach(content_groups)
	}//if(layout[groups] != "")
	$smarty->assign("tpl_group", $tpl_group);


	$smarty->display("ko_pdf_daten_html.tpl");
}//ko_pdf_daten_render_html()




function ko_pdf_daten_render_pdf($id) {
	global $ko_path, $access;

	if($access['daten']['MAX'] < 4) return FALSE;

	//Layout-Daten holen
	ko_get_pdf_daten_layout($layout, $id);
	$header_id = $layout[$id]["header_id"];
	$footer_id = $layout[$id]["footer_id"];
	$group_ids = explode(",", $layout[$id]["groups"]);

	include($ko_path."daten/inc/pdf_daten.inc");
	ko_pdf_daten_start($id);

	ko_pdf_daten_header($header_id);

	foreach($group_ids as $g) {
		ko_pdf_daten_group($g);
	}

	ko_pdf_daten_footer($footer_id);

	$filename = $ko_path."download/pdf/".getLL("daten_export_filename").strftime("%d%m%Y_%H%M%S", time()).".pdf";
	ko_pdf_daten_end($filename);
	return $filename;
}//ko_pdf_daten_render_pdf()




function do_del_termin($del_id) {
	global $access;

  ko_get_event_by_id($del_id, $del_event);
	if($access['daten'][$del_event['eventgruppen_id']] < 2) return FALSE;
  ko_get_eventgruppe_by_id($del_event["eventgruppen_id"], $del_eventgruppe);

	//Moderated events may only be deleted directly with edit rights
	if($del_eventgruppe["moderation"] > 0 && $access['daten'][$del_event['eventgruppen_id']] < 3) {
		//Moderated delete
		$mod_event = $del_event;
		unset($mod_event["id"]);
		$mod_event["_event_id"] = $del_id;
		$mod_event["_delete"] = 1;
		$mod_event["resitems"] = $mod_event["reservationen"]; unset($mod_event["reservationen"]);

		ko_daten_store_moderation(array($mod_event));
		return "mod";
	}

	//Really delete event
	else {
		$log_message  = $del_eventgruppe["name"].": ".sql2datum($del_event["startdatum"]);
		$log_message .= ($del_event["startdatum"] != $del_event["enddatum"])?"-".sql2datum($del_event["enddatum"]):"";
		$log_message .= " (".substr($del_event["startzeit"],0,-3)."-".substr($del_event["endzeit"],0,-3).") in ".$del_event["room"];
		$log_message .= ', "'.$del_event["kommentar"].'"';

		//Die verbundenen Reservationen lschen
		if($del_event["reservationen"]) {
			$del_res = explode(",", $del_event["reservationen"]);
			foreach($del_res as $d) {
				ko_get_res_by_id($d, $r_);
				$r = $r_[$d];
				ko_get_resitem_by_id($r["item_id"], $ri);
				$log_message2  = $d." (Event-Res ".$del_id."): ".$ri[$r["item_id"]]["name"].", ";
				$log_message2 .= sql2datum($r["startdatum"]).($r["startdatum"]!=$r["enddatum"]?"-".sql2datum($r["enddatum"]):"").", ";
				$log_message2 .= substr(format_userinput($r["startzeit"], "text"),0,-3)."-".substr(format_userinput($r["endzeit"], "text"),0,-3);
				$log_message2 .= ', "'.format_userinput($r["zweck"], "text").'", ';
				$log_message2 .= format_userinput($r["name"], "text")." (".format_userinput($r["email"], "text").", ".format_userinput($r["telefon"], "text").")";

				db_delete_data("ko_reservation", "WHERE `id` = '$d'");

				ko_log("delete_res", $log_message2);
			}//foreach(del_res as d)
		}//if(del_event[reservationen])

		//Delete event itself
		db_delete_data("ko_event", "WHERE `id` = '$del_id'");

		//Delete mod entries for this event
		db_delete_data("ko_event_mod", "WHERE `_event_id` = '$del_id'");

		//Send notification
		ko_daten_send_notification($del_event, 'delete');

		ko_log("delete_termin", $log_message);
		return "del";
	}
}//do_del_termin()



/**
  * Finds and deletes empty calendars (withouth any event groups)
	* Must be called after editing and deleting event groups
	*/
function ko_delete_empty_calendars() {
	ko_get_event_calendar($cals);
	foreach($cals as $id => $cal) {
		$count = db_get_count("ko_eventgruppen", "id", "AND `calendar_id` = '$id'");
		if($count == 0) db_delete_data("ko_event_calendar", "WHERE `id` = '$id'");
	}
}//ko_delete_empty_calendars()



function ko_daten_store_moderation($data) {
	$txt = array();
	$egs = db_select_data("ko_eventgruppen", "WHERE 1=1", "*");

	foreach($data as $event) {
		$eg = $egs[$event["eventgruppen_id"]];

		unset($event["id"]);
		$event["_user_id"] = $_SESSION["ses_userid"];
		$event["_crdate"] = strftime("%Y-%m-%d %H:%M:%S", time());

		db_insert_data("ko_event_mod", $event);

		if($eg["moderation"] == 2) {
			$txt = ko_daten_infotext($event);
			$mod_txt[$eg["id"]] .= $txt."\n\n";
			if($event["_delete"] == 1) {
				$subject = getLL("daten_email_mod_delete_mod_subject");
			} else if($event["_event_id"] != 0) {
				$subject = getLL("daten_email_mod_edit_mod_subject");
			} else {
				$subject = getLL("daten_email_mod_subject");
			}
		}
	}

	//Get email of currently logged in user to use it as sender for the mails to the moderators
	if($_SESSION["ses_userid"] != ko_get_guest_id()) {
		$p = ko_get_logged_in_person();
		if($p['email']) {
			if($p['vorname'] || $p['nachname']) {
				$sender_email = '"'.$p['vorname'].' '.$p['nachname'].'" <'.$p['email'].'>';
			} else {
				$sender_email = '"'.$_SESSION['ses_username'].'" <'.$p['email'].'>';
			}
		} else {
			$sender_email = '';
		}
	}
	$headers = array("From" => ($sender_email ? $sender_email : ko_get_setting("info_email")) );

	//Send email to moderators
	foreach($mod_txt as $gid => $txt) {
		if(!$txt || !$gid) continue;
		$mailtext = str_replace("[DATA]", "\n\n".$txt, getLL("daten_email_mod_text"));
		$mods = ko_get_moderators_by_eventgroup($gid);
		foreach($mods as $mod) {
			ko_send_email($mod["email"], "[kOOL] $subject", ko_emailtext($mailtext), $headers);
		}
	}
}//ko_daten_store_moderation()




function ko_daten_update_event($id, $data, &$error_txt="") {
	global $access;

	$error = 0;

	$userid = $data["_user_id"] ? $data["_user_id"] : $_SESSION["ses_userid"];

	ko_get_event_by_id($id, $event);
	ko_get_eventgruppe_by_id($data["eventgruppen_id"], $eg);
	$event["startzeit"] = sql_zeit($event["startzeit"]);
	$event["endzeit"] = sql_zeit($event["endzeit"]);

	$current_res = db_select_data("ko_reservation", "WHERE `id` IN ('".implode("','", explode(",", $event["reservationen"]))."')", "*");
	if(sizeof($current_res) > 0 || $data["resitems"] != "") {
		//Get access rights for reservations
		ko_get_access('reservation');

		//Check for changes which force an update for the reservations for this event
		$update_res = array();
		if($event["startdatum"] != $data["startdatum"]) $update_res["startdatum"] = $data["startdatum"];
		if($event["enddatum"] != $data["enddatum"]) $update_res["enddatum"] = $data["enddatum"];
		if($event["eventgruppen_id"] != $data["eventgruppen_id"] || $event["kommentar"] != $data["kommentar"]) {
			$update_res["zweck"] = $data["kommentar"].' ('.$eg["name"].')';
		}
		$update_res["startzeit"] = $data["res_startzeit"];
		$update_res["endzeit"] = $data["res_endzeit"];

		$store_res = $store_mod = array();
		$event_res = array();
		foreach(explode(",", $data["resitems"]) as $iid) {
			$found = FALSE;
			foreach($current_res as $cid => $cr) {
				if($cr["item_id"] == $iid) {
					$found = TRUE;
					$event_res[] = $cid;
					//TODO: Overlapping check is not done! (ko_res_check_double())
					if(sizeof($update_res) > 0) db_update_data("ko_reservation", "WHERE `id` = '$cid'", $update_res);
					unset($current_res[$cid]);
				}
			}
			if(!$found) {
				if($access['reservation'][$iid] < 2) continue;
				//Add new reservation
				$p = ko_get_logged_in_person();
				$res_data = array("item_id" => $iid,
						"startdatum" => $data["startdatum"],
						"enddatum" => $data["enddatum"],
						"startzeit" => $data["res_startzeit"],
						"endzeit" => $data["res_endzeit"],
						"zweck" => $data["kommentar"].' ('.$eg['name'].')',
						"name" => $p["vorname"]." ".$p["nachname"],
						"email" => $p["email"],
						"telefon" => $p["telp"]);
				$resitem = db_select_data("ko_resitem", "WHERE `id` = '$iid'", "*", "", "", TRUE);
				//Check for res colision
				ko_res_check_double($iid, $res_data["startdatum"], $res_data["enddatum"], $res_data["startzeit"], $res_data["endzeit"], $double_error_txt);
				if($double_error_txt) {
					$error_txt .= "<br />".$double_error_txt;
					$error = 99;
				} else {
					//Check for moderation
					if($resitem["moderation"] > 0 && $access['reservation'][$iid] < 3) {
						$res_data["_event_id"] = $id;
						$store_mod[] = $res_data;
					} else {
						unset($res_data["_event_id"]);
						$store_res[] = $res_data;
					}
				}
			}//if(!found)
		}//foreach(resitems)

		//Store new reservations
		if(sizeof($store_res) > 0) {
			$send_user_email = ko_get_userpref($userid, "do_res_email") != 2;
			$new_ids = ko_res_store_reservation($store_res, $send_user_email);
			$event_res = array_merge($event_res, $new_ids);
		}
		if(sizeof($store_mod) > 0) {
			ko_res_store_moderation($store_mod);
		}
		//Delete reservations not selected anymore
		if(sizeof($current_res) > 0) {
			foreach($current_res as $cr) db_delete_data("ko_reservation", "WHERE `id` = '".$cr["id"]."'");
		}

		$data["reservationen"] = implode(",", $event_res);
	}//if(handle_res)

	//Update event itself
	$unset = array("resitems", "res_startzeit", "res_endzeit", "id");
	foreach($data as $key => $value) {
		if(substr($key, 0, 1) == "_" || in_array($key, $unset)) unset($data[$key]);
	}
	db_update_data("ko_event", "WHERE `id` = '$id'", $data);

	//Send notification
	ko_daten_send_notification($data, 'update', $event);

	//Log-Meldung erstellen
	ko_log_diff("edit_termin", array_merge(array("name" => $eventgroup["name"]), $data));
	
	return $error;
}//ko_daten_update_event()





function ko_daten_infotext($data) {
	$txt = "";
	$list = kota_get_list($data, "ko_event");
	foreach($list as $key => $value) {
		if($key == getLL("kota_ko_event_enddatum") || $key == getLL("kota_ko_event_endzeit")) continue;
		if($value) $txt .= "$key: ".ko_unhtml($value)."\n";
	}

	return $txt;
}//ko_daten_infotext()



function ko_daten_store_event($data, &$error_txt) {
	global $access;

	$error = 0;

	$resitems = db_select_data("ko_resitem", "WHERE 1=1", "*");
	$egs = db_select_data("ko_eventgruppen", "WHERE 1=1", "*");


	$txt3 = array();
	foreach($data as $event) {
		$last_userid = $userid;
		//Use the userid of the user given in data
		//If this is from a moderated event, then the reservations will be done as the original user and not the moderator
		$userid = $event["_user_id"] ? $event["_user_id"] : $_SESSION["ses_userid"];

		//Only get settings again if this event is done by another userid
		if($userid != $last_userid) {
			//Get person data for logged in person
			$p = ko_get_logged_in_person();
			//Get access rights for reservations
			ko_get_access('reservation');
			//Get user setting to send emails for reservations
			$send_user_email = ko_get_userpref($userid, "do_res_email") != 2;
		}

		$eg = $egs[$event["eventgruppen_id"]];

		//Prepare reservations
		$event_res = $res_store = $res_mod = array();
		if($event["resitems"]) {
			//set data for reservations
			$res_data["startdatum"] = $event["startdatum"];
			$res_data["enddatum"] = $event["enddatum"];
			$res_data["startzeit"] = $event["res_startzeit"];
			$res_data["endzeit"] = $event["res_endzeit"];
			$res_data["zweck"] = $event["kommentar"].' ('.$eg['name'].')';
			$res_data["name"] = $p["vorname"]." ".$p["nachname"];
			$res_data["email"] = $p["email"];
			$res_data["telefon"] = $p["telp"];
			$res_data["user_id"] = $userid;  //Store userid also for reservations

			$res_mod = $res_store = array();
			foreach(explode(",", $event["resitems"]) as $r) {
				if(!$r) continue;
				$res_data = array("item_id" => $r)+$res_data;

				//Auf Doppelbelegung prfen
				$do_res = TRUE;
				ko_res_check_double($r, $res_data["startdatum"], $res_data["enddatum"], $res_data["startzeit"], $res_data["endzeit"], $double_error_txt);
				if($double_error_txt) {
					$error_txt .= "<br />".$double_error_txt;
					$error = 99;
					$do_res = FALSE;
				}

				if($do_res) {
					if($resitems[$r]["moderation"] == 0 || $access['reservation'][$r] > 2) {
						$res_store[] = $res_data;
					} else {
						$res_mod[] = $res_data;
					}
				}//if(do_res)
			}//foreach(res_s as r)

			//Store reservations for this event
			if(sizeof($res_store) > 0) {
				$event_res = ko_res_store_reservation($res_store, $send_user_email);
			}
		}//if(sizeof(resitems))

		//Unset values not needed for ko_event (might be from ko_event_mod or just from the submitted form)
		$unset_keys = array("resitems", "id", "res_startzeit", "res_endzeit");
		foreach($event as $key => $value) {
			if(substr($key, 0, 1) == "_" || in_array($key, $unset_keys)) unset($event[$key]);
		}
		$event["reservationen"] = implode(",", $event_res);

		//Store new event
		$new_id = db_insert_data("ko_event", $event);

		if($egs[$event['eventgruppen_id']]['moderation'] > 0 && $access['daten'][$event['eventgruppen_id']] == 3) {
			$txt3[$event["eventgruppen_id"]] .= ko_daten_infotext($event)."\n\n";
		}

		//Store reservation which need moderation (only after new events has been stored, so _event_id may be set
		if(sizeof($res_mod) > 0) {
			//Add event id for these reservations, so they will be associated with the event after moderation
			foreach($res_mod as $res_id => $res) $res_mod[$res_id]["_event_id"] = $new_id;
			ko_res_store_moderation($res_mod);
		}

		//Send notification
		ko_daten_send_notification($event, 'new');

		//Log-Meldung
		ko_log_diff("new_termin", array_merge(array("id" => $new_id), $event));
	}//foreach(data as event)

	//Mail for moderator, if user with access level 3 has made a reservation of a moderated object
	if(sizeof($txt3) > 0) {
		$headers = array("From" => ko_get_setting("info_email"));

		foreach($txt3 as $gid => $txt) {
			$mailtext = sprintf(getLL("daten_email_mod3_text"), ("\n\n".$txt));
			$mods = ko_get_moderators_by_eventgroup($gid);
			foreach($mods as $mod) {
				//Check user_pref for this moderator
				if(ko_get_userpref($mod["id"], "do_mod_email_for_edit_daten") == 1) {
					ko_send_email($mod["email"], "[kOOL] ".getLL("daten_email_mod3_subject"), $mailtext, $headers);
				}
			}
		}
	}

	return $error;
}//ko_daten_store_event()





/**
  * Send notification for event updates if set in the given eventgroup
	* @param array data: new event
	* @param string mode: new, update or delete used for message
	* @param array old: old event data. Used for mode==update to show differences
	*/
function ko_daten_send_notification($data, $mode, $old='') {
	global $DATETIME;

	//Get event if only id is given (used after multiediting)
	if(!is_array($data)) {
		$id = $data;
		ko_get_event_by_id($id, $data);
	}

	//Check eventgroup for notification
	ko_get_eventgruppe_by_id($data['eventgruppen_id'], $eg);
	if($eg['notify'] == '') return;

	//Build SQL to find the persons for the selected groups
	$groups = explode(',', $eg['notify']);
	$sql = '';
	foreach($groups as $gid) {
		if(!$gid) continue;
		$sql .= ' `groups` REGEXP \''.$gid.'\' OR ';
	}
	$sql = substr($sql, 0, -3);
	if(!$sql) return;

	//Get people from DB to send notification to
	ko_get_leute($p, 'AND ('.$sql.')');
	if(sizeof($p) == 0) return;
	$to = array();
	foreach($p as $person) {
		if(!$person['email']) continue;
		$to[] = $person['email'];
	}
	if(sizeof($to) == 0) return;

	//Send email
	$headers = array('From' => ko_get_setting('info_email'));
	$subject = getLL('daten_notify_subject').': '.trim($eg['name']).' '.strftime($DATETIME['dmy'], strtotime($data['startdatum']));
	$message = getLL('daten_notify_message_'.$mode)."\n\n";
	if($mode == 'update' && is_array($old)) {
		$list_new = kota_get_list($data, 'ko_event');
		$list_old = kota_get_list($old, 'ko_event');
		$diff = '';
		foreach($list_old as $k => $v) {
			if($k == getLL('kota_ko_event_enddatum') || $k == getLL('kota_ko_event_endzeit')) continue;
			if($list_new[$k] != $v) $diff .= $k.': '.$v.' -> '.$list_new[$k]."\n";
		}
		if($diff) $message .= $diff."\n";
	}
	$message .= ko_daten_infotext($data);

	foreach($to as $recipient) {
		ko_send_email($recipient, $subject, $message, $headers);
	}
}//ko_daten_send_notification()




function ko_daten_get_eg_css() {
	$css = '<style type="text/css">
<!--
';

	ko_get_eventgruppen($egs);
	foreach($egs as $eg) {
		if(!$eg['farbe']) $eg['farbe'] = 'aaaaaa';
		$css .= '.eg'.$eg['id'].', .eg'.$eg['id'].' a, .eg'.$eg['id'].' a:link, .eg'.$eg['id'].' a:visited, .eg'.$eg['id'].' a:hover, .eg'.$eg['id'].' a:active { ';
		$css .= 'background-color: #'.$eg['farbe'].'; ';
		$css .= 'border-color: #'.$eg['farbe'].'; ';
		$css .= 'color: '.ko_get_contrast_color($eg['farbe']).'; ';
		$css .= '}'."\n";
	}

	$css .= '
-->
</style>';

	return $css;
}//ko_daten_get_eg_css()




?>
